==> tuia-advert-center-api-2.2.44-sources.jar: cn/com/duiba/tuia/core/api/dto/req/advert/material/ReqMaterialAuditQueryDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.advert.material;

import cn.com.duiba.tuia.core.api.statistics.domain.ByDateQueryReq;

import java.util.List;

/**
 * Created by lizhihui on 2017-07-25 09:45.
 */
public class ReqMaterialAuditQueryDto extends ByDateQueryReq {
    private static final long serialVersionUID = 5479418336563174291L;
    //素材id列表
    private List<Long> ids;
    //激活状态
    private Integer isActivate;
    //审核状态
    private Integer checkStatus;
    /** 兑吧审核状态 ：0-未审核；1-已审核*/
    private Integer duibaCheckStatus;

    private Integer isDefault;

    // 增值素材id
    private List<Long> enids;

    public List<Long> getEnids() {
        return enids;
    }

    public void setEnids(List<Long> enids) {
        this.enids = enids;
    }

    public Integer getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Integer isDefault) {
        this.isDefault = isDefault;
    }

    /**
     * duibaCheckStatus.
     *
     * @return  the duibaCheckStatus
     * @since   JDK 1.8
     */
    public Integer getDuibaCheckStatus() {
        return duibaCheckStatus;
    }
    
    /**
     * duibaCheckStatus.
     *
     * @param   duibaCheckStatus    the duibaCheckStatus to set
     * @since   JDK 1.8
     */
    public void setDuibaCheckStatus(Integer duibaCheckStatus) {
        this.duibaCheckStatus = duibaCheckStatus;
    }

    public Integer getIsActivate() {
        return isActivate;
    }

    public void setIsActivate(Integer isActivate) {
        this.isActivate = isActivate;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }
}

==> tuia-advert-center-api-2.2.78-sources.jar: cn/com/duiba/tuia/core/api/dto/req/advert/material/ReqMaterialAuditQueryDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.advert.material;

import cn.com.duiba.tuia.core.api.statistics.domain.ByDateQueryReq;

import java.util.List;

/**
 * Created by lizhihui on 2017-07-25 09:45.
 */
public class ReqMaterialAuditQueryDto extends ByDateQueryReq {
    private static final long serialVersionUID = 5479418336563174291L;
    //素材id列表
    private List<Long> ids;
    //激活状态
    private Integer isActivate;
    //审核状态
    private Integer checkStatus;
    /** 兑吧审核状态 ：0-未审核；1-已审核*/
    private Integer duibaCheckStatus;

    private Integer isDefault;

    // 增值素材id
    private List<Long> enids;

    /**
     * 素材新类型
     */
    private List<Integer> newMaterialTypeList;

    public List<Long> getEnids() {
        return enids;
    }

    public void setEnids(List<Long> enids) {
        this.enids = enids;
    }

    public Integer getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Integer isDefault) {
        this.isDefault = isDefault;
    }

    /**
     * duibaCheckStatus.
     *
     * @return  the duibaCheckStatus
     * @since   JDK 1.8
     */
    public Integer getDuibaCheckStatus() {
        return duibaCheckStatus;
    }
    
    /**
     * duibaCheckStatus.
     *
     * @param   duibaCheckStatus    the duibaCheckStatus to set
     * @since   JDK 1.8
     */
    public void setDuibaCheckStatus(Integer duibaCheckStatus) {
        this.duibaCheckStatus = duibaCheckStatus;
    }

    public Integer getIsActivate() {
        return isActivate;
    }

    public void setIsActivate(Integer isActivate) {
        this.isActivate = isActivate;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public List<Integer> getNewMaterialTypeList() {
        return newMaterialTypeList;
    }

    public void setNewMaterialTypeList(List<Integer> newMaterialTypeList) {
        this.newMaterialTypeList = newMaterialTypeList;
    }
}
